## Changelog 

### Added

- [alpha] Support for downloading timeseries/events/files, `cdf data
download timeseries/events/files`.

### Removed

- [alpha] Downloading assets no longer supports selecting an hierarchy.
Use the `cdf ddata download hierarchy` instead.